/****************************************************************************
** Meta object code from reading C++ file 'task.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kcron-26.07.80/src/task.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'task.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4TaskE_t {};
} // unnamed namespace

template <> constexpr inline auto Task::qt_create_metaobjectdata<qt_meta_tag_ZN4TaskE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Task",
        "commentChanged",
        "",
        "commandChanged",
        "userLoginChanged",
        "enabledChanged",
        "rebootChanged",
        "systemCronChanged",
        "applied",
        "canceled",
        "apply",
        "cancel",
        "hasChanges",
        "schedulingCronFormat",
        "describe",
        "isEveryDay",
        "isMonthEnabled",
        "month",
        "isDayOfMonthEnabled",
        "day",
        "isWeekDayEnabled",
        "isHourEnabled",
        "hour",
        "isMinuteEnabled",
        "minute",
        "setMonthEnabled",
        "enabled",
        "setDayOfMonthEnabled",
        "setDayOfWeekEnabled",
        "setHourEnabled",
        "setMinuteEnabled",
        "comment",
        "command",
        "userLogin",
        "reboot",
        "systemCron"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'commentChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'commandChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'userLoginChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'rebootChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'systemCronChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'applied'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'canceled'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'apply'
        QtMocHelpers::MethodData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'cancel'
        QtMocHelpers::MethodData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'hasChanges'
        QtMocHelpers::MethodData<bool() const>(12, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'schedulingCronFormat'
        QtMocHelpers::MethodData<QString() const>(13, 2, QMC::AccessPublic, QMetaType::QString),
        // Method 'describe'
        QtMocHelpers::MethodData<QString() const>(14, 2, QMC::AccessPublic, QMetaType::QString),
        // Method 'isEveryDay'
        QtMocHelpers::MethodData<bool() const>(15, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'isMonthEnabled'
        QtMocHelpers::MethodData<bool(int) const>(16, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 17 },
        }}),
        // Method 'isDayOfMonthEnabled'
        QtMocHelpers::MethodData<bool(int) const>(18, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 19 },
        }}),
        // Method 'isWeekDayEnabled'
        QtMocHelpers::MethodData<bool(int) const>(20, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 19 },
        }}),
        // Method 'isHourEnabled'
        QtMocHelpers::MethodData<bool(int) const>(21, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 22 },
        }}),
        // Method 'isMinuteEnabled'
        QtMocHelpers::MethodData<bool(int) const>(23, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 24 },
        }}),
        // Method 'setMonthEnabled'
        QtMocHelpers::MethodData<void(int, bool)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 }, { QMetaType::Bool, 26 },
        }}),
        // Method 'setDayOfMonthEnabled'
        QtMocHelpers::MethodData<void(int, bool)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 19 }, { QMetaType::Bool, 26 },
        }}),
        // Method 'setDayOfWeekEnabled'
        QtMocHelpers::MethodData<void(int, bool)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 19 }, { QMetaType::Bool, 26 },
        }}),
        // Method 'setHourEnabled'
        QtMocHelpers::MethodData<void(int, bool)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 22 }, { QMetaType::Bool, 26 },
        }}),
        // Method 'setMinuteEnabled'
        QtMocHelpers::MethodData<void(int, bool)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 24 }, { QMetaType::Bool, 26 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'comment'
        QtMocHelpers::PropertyData<QString>(31, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 0),
        // property 'command'
        QtMocHelpers::PropertyData<QString>(32, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 1),
        // property 'userLogin'
        QtMocHelpers::PropertyData<QString>(33, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 2),
        // property 'enabled'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 3),
        // property 'reboot'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 4),
        // property 'systemCron'
        QtMocHelpers::PropertyData<bool>(35, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 5),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Task, qt_meta_tag_ZN4TaskE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Task::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4TaskE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4TaskE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4TaskE_t>.metaTypes,
    nullptr
} };

void Task::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Task *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->commentChanged(); break;
        case 1: _t->commandChanged(); break;
        case 2: _t->userLoginChanged(); break;
        case 3: _t->enabledChanged(); break;
        case 4: _t->rebootChanged(); break;
        case 5: _t->systemCronChanged(); break;
        case 6: _t->applied(); break;
        case 7: _t->canceled(); break;
        case 8: _t->apply(); break;
        case 9: _t->cancel(); break;
        case 10: { bool _r = _t->hasChanges();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 11: { QString _r = _t->schedulingCronFormat();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 12: { QString _r = _t->describe();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 13: { bool _r = _t->isEveryDay();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 14: { bool _r = _t->isMonthEnabled((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 15: { bool _r = _t->isDayOfMonthEnabled((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 16: { bool _r = _t->isWeekDayEnabled((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 17: { bool _r = _t->isHourEnabled((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 18: { bool _r = _t->isMinuteEnabled((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 19: _t->setMonthEnabled((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 20: _t->setDayOfMonthEnabled((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 21: _t->setDayOfWeekEnabled((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 22: _t->setHourEnabled((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 23: _t->setMinuteEnabled((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Task::*)()>(_a, &Task::commentChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Task::*)()>(_a, &Task::commandChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Task::*)()>(_a, &Task::userLoginChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Task::*)()>(_a, &Task::enabledChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Task::*)()>(_a, &Task::rebootChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Task::*)()>(_a, &Task::systemCronChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Task::*)()>(_a, &Task::applied, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Task::*)()>(_a, &Task::canceled, 7))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->comment(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->command(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->userLogin(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->enabled(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->reboot(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->systemCron(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setComment(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setCommand(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setUserLogin(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setReboot(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setSystemCron(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Task::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Task::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4TaskE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Task::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 24)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 24;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void Task::commentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Task::commandChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Task::userLoginChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Task::enabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Task::rebootChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Task::systemCronChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Task::applied()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Task::canceled()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
