/****************************************************************************
** Meta object code from reading C++ file 'variablesmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kcron-26.07.80/src/variablesmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'variablesmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14VariablesModelE_t {};
} // unnamed namespace

template <> constexpr inline auto VariablesModel::qt_create_metaobjectdata<qt_meta_tag_ZN14VariablesModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "VariablesModel",
        "addVariable",
        "",
        "Variable*",
        "variable",
        "modifyVariable",
        "removeVariable",
        "refresh",
        "CTCron*",
        "ctCron",
        "create",
        "applyCreate",
        "modify",
        "applyModify",
        "rowCount",
        "QModelIndex",
        "parent",
        "data",
        "QVariant",
        "index",
        "role",
        "setData",
        "value",
        "removeSelected",
        "copy",
        "cut",
        "paste",
        "Roles",
        "NameRole",
        "ValueRole",
        "CommentRole",
        "UserLoginRole",
        "EnabledRole",
        "IconRole",
        "InformationRole"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'addVariable'
        QtMocHelpers::SignalData<void(Variable *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'modifyVariable'
        QtMocHelpers::SignalData<void(Variable *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'removeVariable'
        QtMocHelpers::SignalData<void(Variable *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'refresh'
        QtMocHelpers::SlotData<void(CTCron *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Method 'create'
        QtMocHelpers::MethodData<Variable *()>(10, 2, QMC::AccessPublic, 0x80000000 | 3),
        // Method 'applyCreate'
        QtMocHelpers::MethodData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'modify'
        QtMocHelpers::MethodData<Variable *()>(12, 2, QMC::AccessPublic, 0x80000000 | 3),
        // Method 'applyModify'
        QtMocHelpers::MethodData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'rowCount'
        QtMocHelpers::MethodData<int(const QModelIndex &) const>(14, 2, QMC::AccessPublic, QMetaType::Int, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Method 'rowCount'
        QtMocHelpers::MethodData<int() const>(14, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Int),
        // Method 'data'
        QtMocHelpers::MethodData<QVariant(const QModelIndex &, int) const>(17, 2, QMC::AccessPublic, 0x80000000 | 18, {{
            { 0x80000000 | 15, 19 }, { QMetaType::Int, 20 },
        }}),
        // Method 'data'
        QtMocHelpers::MethodData<QVariant(const QModelIndex &) const>(17, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 18, {{
            { 0x80000000 | 15, 19 },
        }}),
        // Method 'setData'
        QtMocHelpers::MethodData<bool(const QModelIndex &, const QVariant &, int)>(21, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 15, 19 }, { 0x80000000 | 18, 22 }, { QMetaType::Int, 20 },
        }}),
        // Method 'removeSelected'
        QtMocHelpers::MethodData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'copy'
        QtMocHelpers::MethodData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'cut'
        QtMocHelpers::MethodData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'paste'
        QtMocHelpers::MethodData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Roles'
        QtMocHelpers::EnumData<enum Roles>(27, 27, QMC::EnumFlags{}).add({
            {   28, Roles::NameRole },
            {   29, Roles::ValueRole },
            {   30, Roles::CommentRole },
            {   31, Roles::UserLoginRole },
            {   32, Roles::EnabledRole },
            {   33, Roles::IconRole },
            {   34, Roles::InformationRole },
        }),
    };
    return QtMocHelpers::metaObjectData<VariablesModel, qt_meta_tag_ZN14VariablesModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject VariablesModel::staticMetaObject = { {
    QMetaObject::SuperData::link<GenericModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14VariablesModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14VariablesModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14VariablesModelE_t>.metaTypes,
    nullptr
} };

void VariablesModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<VariablesModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->addVariable((*reinterpret_cast<std::add_pointer_t<Variable*>>(_a[1]))); break;
        case 1: _t->modifyVariable((*reinterpret_cast<std::add_pointer_t<Variable*>>(_a[1]))); break;
        case 2: _t->removeVariable((*reinterpret_cast<std::add_pointer_t<Variable*>>(_a[1]))); break;
        case 3: _t->refresh((*reinterpret_cast<std::add_pointer_t<CTCron*>>(_a[1]))); break;
        case 4: { Variable* _r = _t->create();
            if (_a[0]) *reinterpret_cast<Variable**>(_a[0]) = std::move(_r); }  break;
        case 5: _t->applyCreate(); break;
        case 6: { Variable* _r = _t->modify();
            if (_a[0]) *reinterpret_cast<Variable**>(_a[0]) = std::move(_r); }  break;
        case 7: _t->applyModify(); break;
        case 8: { int _r = _t->rowCount((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 9: { int _r = _t->rowCount();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 10: { QVariant _r = _t->data((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QVariant*>(_a[0]) = std::move(_r); }  break;
        case 11: { QVariant _r = _t->data((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariant*>(_a[0]) = std::move(_r); }  break;
        case 12: { bool _r = _t->setData((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 13: _t->removeSelected(); break;
        case 14: _t->copy(); break;
        case 15: _t->cut(); break;
        case 16: _t->paste(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (VariablesModel::*)(Variable * )>(_a, &VariablesModel::addVariable, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (VariablesModel::*)(Variable * )>(_a, &VariablesModel::modifyVariable, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (VariablesModel::*)(Variable * )>(_a, &VariablesModel::removeVariable, 2))
            return;
    }
}

const QMetaObject *VariablesModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *VariablesModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14VariablesModelE_t>.strings))
        return static_cast<void*>(this);
    return GenericModel::qt_metacast(_clname);
}

int VariablesModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = GenericModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 17;
    }
    return _id;
}

// SIGNAL 0
void VariablesModel::addVariable(Variable * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void VariablesModel::modifyVariable(Variable * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void VariablesModel::removeVariable(Variable * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
