/****************************************************************************
** Meta object code from reading C++ file 'kcmCron.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kcron-26.07.80/src/kcmCron.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kcmCron.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7KCMCronE_t {};
} // unnamed namespace

template <> constexpr inline auto KCMCron::qt_create_metaobjectdata<qt_meta_tag_ZN7KCMCronE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KCMCron",
        "isPersonalUseChanged",
        "",
        "showError",
        "errorString",
        "details",
        "showOnboarding",
        "load",
        "save",
        "defaults",
        "addTask",
        "Task*",
        "task",
        "addVariable",
        "Variable*",
        "variable",
        "modifyTask",
        "modifyVariable",
        "removeTask",
        "removeVariable",
        "onMainUiReady",
        "print",
        "refreshPages",
        "tasksModel",
        "TasksModel*",
        "variablesModel",
        "VariablesModel*",
        "isPersonalUse",
        "userList"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'isPersonalUseChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showError'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 }, { QMetaType::QString, 5 },
        }}),
        // Signal 'showError'
        QtMocHelpers::SignalData<void(const QString &)>(3, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'showOnboarding'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'load'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'save'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'defaults'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addTask'
        QtMocHelpers::SlotData<void(Task *)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'addVariable'
        QtMocHelpers::SlotData<void(Variable *)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'modifyTask'
        QtMocHelpers::SlotData<void(Task *)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'modifyVariable'
        QtMocHelpers::SlotData<void(Variable *)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'removeTask'
        QtMocHelpers::SlotData<void(Task *)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'removeVariable'
        QtMocHelpers::SlotData<void(Variable *)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'onMainUiReady'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Method 'print'
        QtMocHelpers::MethodData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'refreshPages'
        QtMocHelpers::MethodData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'tasksModel'
        QtMocHelpers::PropertyData<TasksModel*>(23, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'variablesModel'
        QtMocHelpers::PropertyData<VariablesModel*>(25, 0x80000000 | 26, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'isPersonalUse'
        QtMocHelpers::PropertyData<bool>(27, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'userList'
        QtMocHelpers::PropertyData<QStringList>(28, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KCMCron, qt_meta_tag_ZN7KCMCronE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KCMCron::staticMetaObject = { {
    QMetaObject::SuperData::link<KQuickManagedConfigModule::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KCMCronE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KCMCronE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7KCMCronE_t>.metaTypes,
    nullptr
} };

void KCMCron::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KCMCron *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->isPersonalUseChanged(); break;
        case 1: _t->showError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 2: _t->showError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->showOnboarding(); break;
        case 4: _t->load(); break;
        case 5: _t->save(); break;
        case 6: _t->defaults(); break;
        case 7: _t->addTask((*reinterpret_cast<std::add_pointer_t<Task*>>(_a[1]))); break;
        case 8: _t->addVariable((*reinterpret_cast<std::add_pointer_t<Variable*>>(_a[1]))); break;
        case 9: _t->modifyTask((*reinterpret_cast<std::add_pointer_t<Task*>>(_a[1]))); break;
        case 10: _t->modifyVariable((*reinterpret_cast<std::add_pointer_t<Variable*>>(_a[1]))); break;
        case 11: _t->removeTask((*reinterpret_cast<std::add_pointer_t<Task*>>(_a[1]))); break;
        case 12: _t->removeVariable((*reinterpret_cast<std::add_pointer_t<Variable*>>(_a[1]))); break;
        case 13: _t->onMainUiReady(); break;
        case 14: _t->print(); break;
        case 15: _t->refreshPages(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KCMCron::*)()>(_a, &KCMCron::isPersonalUseChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMCron::*)(const QString & , const QString & )>(_a, &KCMCron::showError, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KCMCron::*)()>(_a, &KCMCron::showOnboarding, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<TasksModel**>(_v) = _t->tasksModel(); break;
        case 1: *reinterpret_cast<VariablesModel**>(_v) = _t->variablesModel(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->isPersonalUse(); break;
        case 3: *reinterpret_cast<QStringList*>(_v) = _t->userList(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 2: _t->setIsPersonalUse(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KCMCron::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KCMCron::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KCMCronE_t>.strings))
        return static_cast<void*>(this);
    return KQuickManagedConfigModule::qt_metacast(_clname);
}

int KCMCron::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KQuickManagedConfigModule::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 16;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void KCMCron::isPersonalUseChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KCMCron::showError(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 3
void KCMCron::showOnboarding()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
